<?php

require_once NIC_BASE . '/lib/Device/SNMP.php';

/**
 * Nic_Device_jetdirect:: Nic_Device implementation to retrieve data
 * from a HP JetDirect Printer server via SNMP.
 *
 * @author  Mike Cochrane <mike@graftonhall.co.nz>
 * @since   Nic 0.2
 * @package Nic
 */
class Nic_Device_jetdirect extends Nic_Device_SNMP {

    /* SNMP Object ID's to retrieve */
    var $oids = array(
        array('name' => 'Uptime', 'oid' => '.1.3.6.1.2.1.1.3.0', 'storeable' => false),
        array('name' => 'Status', 'oid' => '.1.3.6.1.4.1.11.2.3.9.1.1.3.0', 'storeable' => false),
        array('name' => 'Sys Name', 'oid' => '.iso.org.dod.internet.mgmt.mib-2.system.sysName.0', 'storeable' => false),
        array('name' => 'Sys Location', 'oid' => '.iso.org.dod.internet.mgmt.mib-2.system.sysLocation.0', 'storeable' => false),
        array('name' => 'Engine Page Count', 'oid' => '.1.3.6.1.2.1.43.10.2.1.4.1.1', 'storeable' => true),
        array('name' => 'TCP - Active Opens', 'oid' => 'tcp.tcpActiveOpens.0', 'storeable' => true),
        array('name' => 'TCP - Passive Opens', 'oid' => 'tcp.tcpPassiveOpens.0', 'storeable' => true),
        array('name' => 'TCP - Currently Established', 'oid' => 'tcp.tcpCurrEstab.0', 'storeable' => true, 'data_type' => NIC_DATA_GAUGE),
        array('name' => 'TCP - Out Segments', 'oid' => 'tcp.tcpOutSegs.0', 'storeable' => true),
        array('name' => 'TCP - In Segments', 'oid' => 'tcp.tcpInSegs.0', 'storeable' => true),
        array('name' => 'TCP - Retransmitted Segments', 'oid' => 'tcp.tcpRetransSegs.0', 'storeable' => true),
        array('name' => 'SNMP - In Packets', 'oid' => 'snmp.snmpInPkts.0', 'storeable' => true),
        array('name' => 'SNMP - Out Packets', 'oid' => 'snmp.snmpOutPkts.0', 'storeable' => true),
        array('name' => 'UDP - In Datagrams', 'oid' => 'udp.udpInDatagrams.0', 'storeable' => true),
        array('name' => 'UDP - Out Datagrams', 'oid' => 'udp.udpOutDatagrams.0', 'storeable' => true),
        array('name' => 'ICMP - In Msgs', 'oid' => 'icmp.icmpInMsgs.0', 'storeable' => true),
        array('name' => 'ICMP - Out Msgs', 'oid' => 'icmp.icmpOutMsgs.0', 'storeable' => true),
        array('name' => 'ICMP - In Echo Replies', 'oid' => 'icmp.icmpInEchoReps.0', 'storeable' => true),
        array('name' => 'ICMP - Out Echos', 'oid' => 'icmp.icmpOutEchos.0', 'storeable' => true),
        array('name' => 'ICMP - In Echos', 'oid' => 'icmp.icmpInEchos.0', 'storeable' => true),
        array('name' => 'ICMP - Out Echo Replies', 'oid' => 'icmp.icmpOutEchoReps.0', 'storeable' => true),
    );

    /* Array containing the details of graphs available for this device */
    var $_graphs = array(
        array(
            'title' => 'Printer Usage',
            'axisLabel' => 'Pages / Minute',
            'data' => array(
                array(
                    'source' => 'Engine Page Count',
                    'legend' => 'Pages Per Minute',
                    'description' => 'The number of pages per second being printed.',
                    'type' => NIC_DATA_COUNTER,
                    'scale_function' => '*',
                    'scale_factor' => 60,
                )
            )
        ),
        array(
            'title' => 'TCP/IP',
            'axisLabel' => 'Segments / Second',
            'data' => array(
                array(
                    'source' => 'TCP - Out Segments',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Segments Sent',
                    'description' => 'The rate at which segments are being sent from this server to clients.',
                ),
                array(
                    'source' => 'TCP - In Segments',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Segments Recieved',
                    'description' => 'The rate at which segments are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'SNMP',
            'axisLabel' => 'Packets / Second',
            'data' => array(
                array(
                    'source' => 'SNMP - Out Packets',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Packets Sent',
                    'description' => 'The rate at which packets are being sent from this server to clients.',
                ),
                array(
                    'source' => 'SNMP - In Packets',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Packets Recieved',
                    'description' => 'The rate at which packets are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'UDP',
            'axisLabel' => 'Datagrams / Second',
            'data' => array(
                array(
                    'source' => 'UDP - Out Datagrams',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Datagrams Sent',
                    'description' => 'The rate at which datagrams are being sent from this server to clients.',
                ),
                array(
                    'source' => 'UDP - In Datagrams',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Datagrams Recieved',
                    'description' => 'The rate at which datagrams are being recieved by this server from clients.',
                )
            ),
        ),
        array(
            'title' => 'ICMP',
            'axisLabel' => 'Messages / Second',
            'data' => array(
                array(
                    'source' => 'ICMP - Out Msgs',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Messages Sent',
                    'description' => 'The rate at which messages are being sent from this server to clients.',
                ),
                array(
                    'source' => 'ICMP - In Msgs',
                    'type' => NIC_DATA_COUNTER,
                    'legend' => 'Messages Recieved',
                    'description' => 'The rate at which messages are being recieved by this server from clients.',
                )
            ),
        ),
    );

    function Nic_Device_jetdirect($params = array())
    {
        $this->params = $params;
        if (!isset($this->params['timeout'])) {
            $this->params['timeout'] = 10;
        }
    }

    function getStatus()
    {
        $deviceStatus = @snmpget ($this->params['hostspec'] . ':' . $this->params['port'], $this->params['community'], ".1.3.6.1.4.1.11.2.3.9.1.1.3.0", $this->params['timeout']);
        $deviceStatus = $this->_cleanResponse($deviceStatus);

        $status = array();
        $status['status'] = NIC_STATUS_NORMAL;
        $status['message'] = '';

        if ($deviceStatus === false) {
            $status['status'] = NIC_STATUS_FAULT;
            $status['message'] = '';
        } else {
            switch ($deviceStatus) {
                case '"00 READY"':
                case '"02 WARMING UP"':
                case '"PROCESSING JOB"':
                case '"TRAY EMPTY"':
                case '"CANCELING JOB"':
                    $status['status'] = NIC_STATUS_NORMAL;
                    $status['message'] = $deviceStatus;
                    break;

                case '"12 PRINTER OPEN"':
                case '"13 PAPER JAM"':
                case '"14 NO TONER CART"':
                case 'TRAY MISFEED':
                case '"LASER GLITCH"':
                default:
                    $status['status'] = NIC_STATUS_WARN;
                    $status['message'] = $deviceStatus;
                    break;
            }
        }

        return $status;
    }

}
